@@ -1,32 +1,18 @@
-from wcs.commons.auth import Auth
+from wcs.services.mgrbase import MgrBase
 from wcs.commons.config import MGR_URL
 from wcs.commons.config import logging_folder
 from wcs.commons.http import _get
 from wcs.commons.logme import debug, warning, error 
 
-class WsLive(object):
+class WsLive(MgrBase):
 
-    def __init__(self, auth):
-        self.auth = auth
-        self.mgr_host = MGR_URL
+    def __init__(self, auth,url):
+        super(WsLive, self).__init__(auth,url)
 
-    def gernerate_headers(self,url,body=None):
-        token = self.auth.managertoken(url,body=body)
-        headers = {'Authorization': token}
-        return headers
-
-    def params_parse(self, params):
-        if params:
-            paramlist = []
-            for k, v in params.items():
-                paramlist.append('{0}={1}'.format(k, v))
-            paramlist = '&'.join(paramlist)
-        return paramlist
-   
-    def make_list_url(self, param):
+    def _make_list_url(self, param):
         url = ['{0}/wslive/list'.format(self.mgr_host)] 
         if param:
-            url.append(self.params_parse(param))
+            url.append(super(WsLive, self)._params_parse(param))
         url = '?'.join(url)
         return url
 
@@ -41,10 +27,10 @@ class WsLive(object):
             query['start'] = start
         if limit is not None:
             query['limit'] = limit
-        url = self.make_list_url(query)
+        url = self._make_list_url(query)
         if query is not None:
             debug('List params is %s' % query)
         debug('List bucket %s' % bucket)
-        code, text = _get(url=url, data=query, headers=self.gernerate_headers(url)) 
+        code, text = _get(url=url, data=query, headers=super(WsLive, self)._gernerate_headers(url)) 
         debug('The return code : %d, text : %s' % (code, text))
         return code, text 
